---
title: Spree 3.4.0
section: release_notes
order: 3
---

## Major/New Features

3.4 is a smaller release to lay the groundwork for major new features
described in [Spree Development Roadmap](https://github.com/spree/spree/milestones?direction=asc&sort=due_date&state=open).
It also contains number of bug fixes and improvements besides described in this document.

### Enhanced codebase quality

We've removed tons of unused & deprecated code and on top of that, we've updated
RuboCop rules and tidied up the code quality of all Spree modules.

Contributed to [Spark Solutions](https://github.com/spree/spree/issues/8268)

### Enhanced Segment.com integration

We've added [Segment.com integration in Spree 3.3](https://guides.spreecommerce.org/release_notes/spree_3_3_0.html#segmentcom-tracker-integration)
but it was still limited. Since then we've put a lot of work to implement
tracking of nearly all e-commerce events supported by Segment.com.

Contributed to [Spark Solutions](https://github.com/spree/spree/issues/8264)

### Updated User Documentation

We've updated the entire [User section](https://guides.spreecommerce.org/user/) of
[Spree Documentation](https://guides.spreecommerce.org/) also adding new content describing new features like
[Store Credits](https://guides.spreecommerce.org/user/configuring_store_credit_categories.html).

This is part of our [Guides 2.0 project](https://github.com/spree/spree/issues/8270)

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/8256)

### Searchable Documentation

Thanks to cooperation with [Algolia DocSearch](https://community.algolia.com/docsearch/)
you can easily search the entire [Spree Documentation](https://guides.spreecommerce.org/).

This is part of our [Guides 2.0 project](https://github.com/spree/spree/issues/8270)

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/8300)

### Spree Demo

You can fire up the newest fully functional version of Spree
on Heroku with a just one click :)

[Try it out!](https://heroku.com/deploy?template=https://github.com/spree/spree)

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/8266)

### Spree Frontend views exporter

You can easily copy all of the default spree views into
your project with just one command line:

```bash
rails g spree:frontend:copy_views
```

We hope will make frontend customization easier.

Contributed by [Spark Solutions](https://github.com/spree/spree/issues/8265)

## Upgrade

### Update Gemfile

```ruby
gem 'spree', '~> 3.4.0'
gem 'spree_auth_devise', '~> 3.3'
gem 'spree_gateway', '~> 3.3'
```

### Update your extensions

We're changing how extensions dependencies work. Previously you had to match
extension branch to Spree branch. Starting from Spree 3.2 release `master` branch of all
`spree-contrib` extensions should work with Spree >= `3.1` and < `4.0`. Please change
your extensions in Gemfile eg.:

from:

```ruby
gem 'spree_braintree_vzero', github: 'spree-contrib/spree_braintree_vzero', branch: '3-1-stable'
```

to:

```ruby
gem 'spree_braintree_vzero', github: 'spree-contrib/spree_braintree_vzero'
```

### Run `bundle update`

### Install missing migrations

```bash
rails spree:install:migrations
rails spree_auth:install:migrations
rails spree_gateway:install:migrations
```

### Run migrations

```bash
rails db:migrate
```

### Other Gotchas

#### Migrate Spree::Taxon icons to Spree Assets

We changed `Spree::Taxon` icon to use `Spree::Asset` to unify attachment usage
across all Spree models. If you were using icon images in `Spree::Taxon`
please run this to migrate your icons:

```bash
rails db:migrate_taxon_icons
```

#### Noteworthy Changes

Also please review each of the noteworthy changes, and ensure your customizations
or extensions are not effected. If you are affected by a change, and have any
of your own tips please submit a PR to help the next person!

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/3-3-stable...master).

## Noteworthy Changes

- Moved Admin Panel account menu into Spree core and redesigning it

  [Spark Solutions](https://github.com/spree/spree/pull/8249)

- Better multi store support for Spree frontend (use `current_store` with `last_incomplete_spree_order`)

  [Alexandre Ferraille](https://github.com/spree/spree/pull/8078)

- Added OptionTypes & OptionValues API V1 Documentation

  [Yatindra Rao](https://github.com/spree/spree/pull/8394)

- Removed previously deprecated `Shipment#editable_by?` & `Shipment#send_shipped_email`

  [Spark Solutions](https://github.com/spree/spree/pull/8276)

- Removed previously deprecated `Variant#having_orders` & `Variant#on_backorder`

  [Spark Solutions](https://github.com/spree/spree/pull/8277)

- Removed previously deprecated `DelegateBelongsTo`

  [Spark Solutions](https://github.com/spree/spree/pull/8275)

- Updated `Address#require_phone?` to use `address_requires_phone` preference

  [Spark Solutions](https://github.com/spree/spree/pull/8290)

- Performance optimization - replaced `pluck.sum` and `map.sum` with `sum`

  [Spark Solutions](https://github.com/spree/spree/pull/8283)

- Performance optimization - replaced `.count > 0` with `.exists?`

  [Spark Solutions](https://github.com/spree/spree/pull/8282)

- Removed previously deprecated `Calculator::PercentPerItem`

  [Spark Solutions](https://github.com/spree/spree/pull/8314)

- Removed deprecated `StoreHelper` from frontend

  [Spark Solutions](https://github.com/spree/spree/pull/8316)

- Removed deprecated `TestingSupport::MicroData`

  [Spark Solutions](https://github.com/spree/spree/pull/8315)

- Deprecated `ContentController#show`

  [Spark Solutions](https://github.com/spree/spree/pull/8379)
